// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `QUDT Disciplines Ontology` vocabulary
//!
//! This module requires `ns-discipline` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|QUDT Disciplines Ontology|
//! |**Prefix**|discipline|
//! |**Namespace base IRI**|<http://qudt.org/vocab/discipline/>|
//! |**Description**||
//! |**Is defined by**|<http://qudt.org/vocab/discipline/>|
//!

use crate::namespace;

namespace!(
    "http://qudt.org/vocab/discipline/",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Acoustics`: 
    Acoustics, "Acoustics",
    /// `Aero thermal dynamics`: 
    AeroThermalDynamics, "AeroThermalDynamics",
    /// `Aerodynamics`: 
    Aerodynamics, "Aerodynamics",
    /// `Any`: 
    Any, "Any",
    /// `Artifical gravity`: 
    ArtificalGravity, "ArtificalGravity",
    /// `Astrionics`: 
    Astrionics, "Astrionics",
    /// `Astrobiology`: 
    Astrobiology, "Astrobiology",
    /// `Astrodynamics`: 
    Astrodynamics, "Astrodynamics",
    /// `AtmosphericChemistry`: 
    AtmosphericChemistry, "AtmosphericChemistry",
    /// `AtmosphericPhysics`: 
    AtmosphericPhysics, "AtmosphericPhysics",
    /// `AtmosphericScience`: 
    AtmosphericScience, "AtmosphericScience",
    /// `AtomicPhysics`: 
    AtomicPhysics, "AtomicPhysics",
    /// `Attitude control`: 
    AttitudeControl, "AttitudeControl",
    /// `Autonomy`: 
    Autonomy, "Autonomy",
    /// `Avionics`: 
    Avionics, "Avionics",
    /// `BioChemistry`: 
    BioChemistry, "BioChemistry",
    /// `BioInformatics`: 
    BioInformatics, "BioInformatics",
    /// `Biology`: 
    Biology, "Biology",
    /// `Biomechanics`: 
    Biomechanics, "Biomechanics",
    /// `Celestial mechanics`: 
    CelestialMechanics, "CelestialMechanics",
    /// `CharacteristicNumber`: 
    CharacteristicNumber, "CharacteristicNumber",
    /// `Chemical engineering`: 
    ChemicalEngineering, "ChemicalEngineering",
    /// `Chemical propulsion`: 
    ChemicalPropulsion, "ChemicalPropulsion",
    /// `Chemistry`: 
    Chemistry, "Chemistry",
    /// `ClassicalMechanics`: 
    ClassicalMechanics, "ClassicalMechanics",
    /// `Climatology`: 
    Climatology, "Climatology",
    /// `Commerce`: 
    Commerce, "Commerce",
    /// `Communications`: 
    Communications, "Communications",
    /// `Computer science discipline`: 
    ComputerScience, "ComputerScience",
    /// `Configuration management`: 
    ConfigurationManagement, "ConfigurationManagement",
    /// `ContinuumMechanics`: 
    ContinuumMechanics, "ContinuumMechanics",
    /// `Control engineering`: 
    ControlEngineering, "ControlEngineering",
    /// `Cost estimation`: 
    CostEstimation, "CostEstimation",
    /// `Cryogenics`: 
    Cryogenics, "Cryogenics",
    /// `Currency`: 
    Currency, "Currency",
    /// `Dimensionless`: 
    Dimensionless, "Dimensionless",
    /// `Dynamics`: 
    Dynamics, "Dynamics",
    /// `Economics`: 
    Economics, "Economics",
    /// `Electrical Engineering`: 
    ElectricalEngineering, "ElectricalEngineering",
    /// `ElectricityAndMagnetism`: 
    ElectricityAndMagnetism, "ElectricityAndMagnetism",
    /// `ElectronicEngineering`: 
    ElectronicEngineering, "ElectronicEngineering",
    /// `Energy`: 
    Energy, "Energy",
    /// `Engineering`: 
    Engineering, "Engineering",
    /// `Environment control`: 
    EnvironmentControl, "EnvironmentControl",
    /// `Finance`: 
    Finance, "Finance",
    /// `Fluid dynamics`: 
    FluidDynamics, "FluidDynamics",
    /// `Fluid mechanics`: 
    FluidMechanics, "FluidMechanics",
    /// `Guidance and Navigation`: 
    GuidanceAndNavigation, "GuidanceAndNavigation",
    /// `Human factors`: 
    HumanFactors, "HumanFactors",
    /// `Hydraulics`: 
    Hydraulics, "Hydraulics",
    /// `Hydraulics engineering`: 
    HydraulicsEngineering, "HydraulicsEngineering",
    /// `Hydrodynamics`: 
    Hydrodynamics, "Hydrodynamics",
    /// `Hypersonic aerodynamics`: 
    HypersonicAerodynamics, "HypersonicAerodynamics",
    /// `Informatics`: 
    Informatics, "Informatics",
    /// `Information engineering`: 
    InformationEngineering, "InformationEngineering",
    /// `InformationTheory`: 
    InformationTheory, "InformationTheory",
    /// `Integrated system health monitoriing`: 
    IntegratedSystemHealthMonitoriing, "IntegratedSystemHealthMonitoriing",
    /// `Integrated system health monitoring`: 
    IntegratedSystemHealthMonitoring, "IntegratedSystemHealthMonitoring",
    /// `Integrated vehicle health management`: 
    IntegratedVehicleHealthManagement, "IntegratedVehicleHealthManagement",
    /// `Kinematics`: 
    Kinematics, "Kinematics",
    /// `Knowledge Engineering`: 
    KnowledgeEngineering, "KnowledgeEngineering",
    /// `LifeSciences`: 
    LifeSciences, "LifeSciences",
    /// `Light`: 
    Light, "Light",
    /// `Loads`: 
    Loads, "Loads",
    /// `Loads analysis`: 
    LoadsAnalysis, "LoadsAnalysis",
    /// `Loads and mass properties`: 
    LoadsAndMassProperties, "LoadsAndMassProperties",
    /// `Logistics`: 
    Logistics, "Logistics",
    /// `Macroeconomics`: 
    Macroeconomics, "Macroeconomics",
    /// `Management`: 
    Management, "Management",
    /// `Mass`: 
    Mass, "Mass",
    /// `Mass properties`: 
    MassProperties, "MassProperties",
    /// `MassProperty`: 
    MassProperty, "MassProperty",
    /// `Materials`: 
    Materials, "Materials",
    /// `Materials and structures`: 
    MaterialsAndStructures, "MaterialsAndStructures",
    /// `MaterialsScience`: 
    MaterialsScience, "MaterialsScience",
    /// `Mechanical engineering`: 
    MechanicalEngineering, "MechanicalEngineering",
    /// `Mechanics`: 
    Mechanics, "Mechanics",
    /// `Mechanisms`: 
    Mechanisms, "Mechanisms",
    /// `MedicalInformatics`: 
    MedicalInformatics, "MedicalInformatics",
    /// `Medicine`: 
    Medicine, "Medicine",
    /// `Meteorology`: 
    Meteorology, "Meteorology",
    /// `Mission planning`: 
    MissionPlanning, "MissionPlanning",
    /// `Modeling and simulation`: 
    ModelingAndSimulation, "ModelingAndSimulation",
    /// `NuclearPhysics`: 
    NuclearPhysics, "NuclearPhysics",
    /// `Nuclear power`: 
    NuclearPower, "NuclearPower",
    /// `Nuclear propulsion`: 
    NuclearPropulsion, "NuclearPropulsion",
    /// `Nutrition`: 
    Nutrition, "Nutrition",
    /// `Optics`: 
    Optics, "Optics",
    /// `Orbital mechanics`: 
    OrbitalMechanics, "OrbitalMechanics",
    /// `ParticlePhysics`: 
    ParticlePhysics, "ParticlePhysics",
    /// `Photometry`: 
    Photometry, "Photometry",
    /// `PhysicalConstant`: 
    PhysicalConstant, "PhysicalConstant",
    /// `Physical Scence`: 
    PhysicalScience, "PhysicalScience",
    /// `Physics`: 
    Physics, "Physics",
    /// `Plasma dynamics`: 
    PlasmaDynamics, "PlasmaDynamics",
    /// `PlasmaPhysics`: 
    PlasmaPhysics, "PlasmaPhysics",
    /// `Pressurized systems`: 
    PressurizedSystems, "PressurizedSystems",
    /// `Propulsion`: 
    Propulsion, "Propulsion",
    /// `Propulsion systems design`: 
    PropulsionSystemsDesign, "PropulsionSystemsDesign",
    /// `QuantityValue`: 
    QuantityValue, "QuantityValue",
    /// `QuantumMechanics`: 
    QuantumMechanics, "QuantumMechanics",
    /// `Radiation`: 
    Radiation, "Radiation",
    /// `Radiology`: 
    Radiology, "Radiology",
    /// `Radiometry`: 
    Radiometry, "Radiometry",
    /// `Requirements engineering`: 
    RequirementsEngineering, "RequirementsEngineering",
    /// `Risk Management`: 
    RiskManagement, "RiskManagement",
    /// `Science`: 
    Science, "Science",
    /// `SocialScience`: 
    SocialScience, "SocialScience",
    /// `Software engineering`: 
    SoftwareEngineering, "SoftwareEngineering",
    /// `SolidStatePhysics`: 
    SolidStatePhysics, "SolidStatePhysics",
    /// `SpaceAndTime`: 
    SpaceAndTime, "SpaceAndTime",
    /// `Space System Engineering`: 
    SpaceSystemEngineering, "SpaceSystemEngineering",
    /// `Spectroscopy`: 
    Spectroscopy, "Spectroscopy",
    /// `StatisticalMechanics`: 
    StatisticalMechanics, "StatisticalMechanics",
    /// `Structures`: 
    Structures, "Structures",
    /// `Structures and Mechanics`: 
    StructuresAndMechanics, "StructuresAndMechanics",
    /// `System design`: 
    SystemDesign, "SystemDesign",
    /// `System Engineering`: 
    SystemEngineering, "SystemEngineering",
    /// `System Integration`: 
    SystemIntegration, "SystemIntegration",
    /// `System testing`: 
    SystemTesting, "SystemTesting",
    /// `Systems`: 
    Systems, "Systems",
    /// `Telebiometrics`: 
    Telebiometrics, "Telebiometrics",
    /// `Telemetry`: 
    Telemetry, "Telemetry",
    /// `Thermal control`: 
    ThermalControl, "ThermalControl",
    /// `ThermalEngineering`: 
    ThermalEngineering, "ThermalEngineering",
    /// `Thermal protection`: 
    ThermalProtection, "ThermalProtection",
    /// `Thermodynamics`: 
    Thermodynamics, "Thermodynamics",
    /// `Trade studies`: 
    TradeStudies, "TradeStudies",
    /// `Trajectory`: 
    Trajectory, "Trajectory",
    /// `Trajectory analysis`: 
    TrajectoryAnalysis, "TrajectoryAnalysis",
    /// `Trajectory analysis and design`: 
    TrajectoryAnalysisAndDesign, "TrajectoryAnalysisAndDesign",
    /// `Trajectory design`: 
    TrajectoryDesign, "TrajectoryDesign",
    /// `Vehicle systems design`: 
    VehicleSystemsDesign, "VehicleSystemsDesign",
    /// `Vibration`: 
    Vibration, "Vibration",
    /// `Vibration analysis`: 
    VibrationAnalysis, "VibrationAnalysis"
);
